@@ -234,6 +234,9 @@ EXPECTED_CODES = 'expected_codes'
 FALL_THRESHOLD = 'fall_threshold'
 HEALTHMONITOR = 'healthmonitor'
 HEALTHMONITOR_ID = 'healthmonitor_id'
+HSTS_MAX_AGE = 'hsts_max_age'
+HSTS_INCLUDE_SUBDOMAINS = 'hsts_include_subdomains'
+HSTS_PRELOAD = 'hsts_preload'
 HTTP_METHOD = 'http_method'
 HTTP_VERSION = 'http_version'
 INSERT_HEADERS = 'insert_headers'
@@ -295,4 +298,7 @@ VIP_NETWORK_ID = 'vip_network_id'
 VIP_PORT_ID = 'vip_port_id'
 VIP_SUBNET_ID = 'vip_subnet_id'
 VIP_QOS_POLICY_ID = 'vip_qos_policy_id'
+VNIC_TYPE = 'vnic_type'
+VNIC_TYPE_DIRECT = 'direct'
+VNIC_TYPE_NORMAL = 'normal'
 WEIGHT = 'weight'
